@@ -305,9 +305,9 @@ class Audiences(object):
 
         if not audiences is None:
             data = json.loads(audiences.decode())
-            return [AudienceQuery.from_raw_data(raw_data=d) for d in data]
+            return [AudienceQuery.from_raw_data(raw_data=d) for d in data], data
         else:
-            return None
+            return None, None
 
     @classmethod
     def get_queries_from_db(cls, au_domain):
